<?xml version="1.0" ?><!DOCTYPE TS><TS language="el" version="2.1">
    <context>
        <name>desktop</name>
        <message>
            <location filename="Desktop Entry]Name" line="0"/>
            <source>Deepin Screenshot</source>
            <translation>Στιγμιότυπο οθόνης Deepin</translation>
        </message>
        <message>
            <location filename="Delay_Screenshot Shortcut Group]Name" line="0"/>
            <source>Delay Screenshot</source>
            <translation>Καθυστέρηση στιγμιότυπου οθόνης</translation>
        </message>
        <message>
            <location filename="Full_Screenshot Shortcut Group]Name" line="0"/>
            <source>Full Screenshot</source>
            <translation>Πλήρες στιγμιότυπο οθόνης</translation>
        </message>
        <message>
            <location filename="Desktop Entry]Comment" line="0"/>
            <location filename="Desktop Entry]GenericName" line="0"/>
            <source>Screen capturing application</source>
            <translation>Εφαρμογή καταγραφής οθόνης</translation>
        </message>
    </context>
</TS>